package org.eco.als.service;

import org.eco.als.domain.CarryChecklist;
import org.eco.als.domain.bo.CarryChecklistBo;
import org.eco.als.domain.vo.CarryChecklistVo;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.core.core.page.PageResult;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * 任务携行Service接口
 *
 * @author wgk
 * @date 2024-07-25
 */
public interface ICarryChecklistService extends IBaseService<CarryChecklist> {
    /**
     * 查询任务携行
     *
     * @param id 任务携行主键
     * @return 任务携行
     */
    CarryChecklistVo selectById(Long id);

    /**
     * 查询任务携行列表
     *
     * @param carryChecklistBo 任务携行Bo
     * @return 任务携行集合
     */
    List<CarryChecklistVo> selectList(CarryChecklistBo carryChecklistBo);

    /**
     * 分页查询任务携行列表
     *
     * @param carryChecklistBo 任务携行Bo
     * @return 分页任务携行集合
     */
    PageResult<CarryChecklistVo> selectPage(CarryChecklistBo carryChecklistBo);

    /**
     * 新增任务携行
     *
     * @param carryChecklistBo 任务携行Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(CarryChecklistBo carryChecklistBo);

    /**
     * 新增任务携行，前台提供主键值，一般用于导入的场合
     *
     * @param carryChecklistBo 任务携行Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(CarryChecklistBo carryChecklistBo);

    /**
     * 修改任务携行
     *
     * @param carryChecklistBo 任务携行Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(CarryChecklistBo carryChecklistBo);

    /**
     * 批量删除任务携行
     *
     * @param ids 需要删除的任务携行主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * 异步导入
     *
     * @param file          导入的文件
     * @param updateSupport 是否覆盖
     * @param user          用户上下文信息
     */
    @Async
    void asyncImportData(MultipartFile file, boolean updateSupport, LoginUser user);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<CarryChecklistVo> listVo, String sheetName, LoginUser user);

}
