package org.eco.als.service;

import java.util.List;

import org.eco.als.domain.vo.FaultStatisticsWbVo;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.als.domain.FaultStatistics;
import org.eco.als.domain.vo.FaultStatisticsVo;
import org.eco.als.domain.bo.FaultStatisticsBo;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.web.multipart.MultipartFile;
import org.eco.common.core.core.page.PageResult;

/**
 * 故障统计Service接口
 *
 * @author wgk
 * @date 2024-12-13
 */
public interface IFaultStatisticsService extends IBaseService<FaultStatistics> {
    /**
     * 查询故障统计
     *
     * @param id 故障统计主键
     * @return 故障统计
     */
        FaultStatisticsVo selectById(Long id);
    /**
     * 查询故障统计列表
     *
     * @param faultStatisticsBo 故障统计Bo
     * @return 故障统计集合
     */
    List<FaultStatisticsVo> selectList(FaultStatisticsBo faultStatisticsBo);

    /**
     * 查询故障统计数量
     *
     * @param faultStatisticsBo 故障统计Bo
     * @return 故障统计集合
     */
    public List<FaultStatisticsVo> Statistics(FaultStatisticsBo faultStatisticsBo);

    /**
     * 外部查询故障统计列表
     *
     * @param faultStatisticsBo 故障统计Bo
     * @return 故障统计集合
     */
    public List<FaultStatisticsWbVo> outsideListAll(FaultStatisticsBo faultStatisticsBo);

    /**
     * 分页查询故障统计列表
     *
     * @param faultStatisticsBo 故障统计Bo
     * @return 分页故障统计集合
     */
    PageResult<FaultStatisticsVo> selectPage(FaultStatisticsBo faultStatisticsBo);

    /**
     * 新增故障统计
     *
     * @param faultStatisticsBo 故障统计Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(FaultStatisticsBo faultStatisticsBo);

    /**
     * 新增故障统计，前台提供主键值，一般用于导入的场合
     *
     * @param faultStatisticsBo 故障统计Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(FaultStatisticsBo faultStatisticsBo);

    /**
     * 修改故障统计
     *
     * @param faultStatisticsBo 故障统计Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(FaultStatisticsBo faultStatisticsBo);

    /**
     * 批量删除故障统计
     *
     * @param ids 需要删除的故障统计主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * 异步导入
     *
     * @param file          导入的文件
     * @param updateSupport 是否覆盖
     * @param user          用户上下文信息
     */
    @Async
    void asyncImportData(MultipartFile file, boolean updateSupport, LoginUser user);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<FaultStatisticsVo> listVo, String sheetName, LoginUser user);

}
