package org.eco.als.service;

import org.eco.als.domain.FlightSplitTask;
import org.eco.als.domain.bo.FlightSplitTaskBo;
import org.eco.als.domain.vo.FlightSplitTaskVo;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.core.core.page.PageResult;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * 飞行分解任务Service接口
 *
 * @author wgk
 * @date 2024-07-24
 */
public interface IFlightSplitTaskService extends IBaseService<FlightSplitTask> {
    /**
     * 查询飞行分解任务
     *
     * @param id 飞行分解任务主键
     * @return 飞行分解任务
     */
    FlightSplitTaskVo selectById(Long id);

    /**
     * 查询飞行分解任务列表
     *
     * @param flightSplitTaskBo 飞行分解任务Bo
     * @return 飞行分解任务集合
     */
    List<FlightSplitTaskVo> selectList(FlightSplitTaskBo flightSplitTaskBo);

    /**
     * 分页查询飞行分解任务列表
     *
     * @param flightSplitTaskBo 飞行分解任务Bo
     * @return 分页飞行分解任务集合
     */
    PageResult<FlightSplitTaskVo> selectPage(FlightSplitTaskBo flightSplitTaskBo);

    /**
     * 新增飞行分解任务
     *
     * @param flightSplitTaskBo 飞行分解任务Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(FlightSplitTaskBo flightSplitTaskBo);

    /**
     * 新增飞行分解任务，前台提供主键值，一般用于导入的场合
     *
     * @param flightSplitTaskBo 飞行分解任务Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(FlightSplitTaskBo flightSplitTaskBo);

    /**
     * 修改飞行分解任务
     *
     * @param flightSplitTaskBo 飞行分解任务Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(FlightSplitTaskBo flightSplitTaskBo);

    /**
     * 批量删除飞行分解任务
     *
     * @param ids 需要删除的飞行分解任务主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * 异步导入
     *
     * @param file          导入的文件
     * @param updateSupport 是否覆盖
     * @param user          用户上下文信息
     */
    @Async
    void asyncImportData(MultipartFile file, boolean updateSupport, LoginUser user);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<FlightSplitTaskVo> listVo, String sheetName, LoginUser user);

}
