package org.eco.als.service;

import java.util.List;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.als.domain.JudgeFaultLogic;
import org.eco.als.domain.vo.JudgeFaultLogicVo;
import org.eco.als.domain.bo.JudgeFaultLogicBo;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.web.multipart.MultipartFile;
import org.eco.common.core.core.page.PageResult;

/**
 * 判故逻辑Service接口
 *
 * @author wgk
 * @date 2024-12-11
 */
public interface IJudgeFaultLogicService extends IBaseService<JudgeFaultLogic> {
    /**
     * 查询判故逻辑
     *
     * @param id 判故逻辑主键
     * @return 判故逻辑
     */
        JudgeFaultLogicVo selectById(Long id);
    /**
     * 查询判故逻辑列表
     *
     * @param judgeFaultLogicBo 判故逻辑Bo
     * @return 判故逻辑集合
     */
    List<JudgeFaultLogicVo> selectList(JudgeFaultLogicBo judgeFaultLogicBo);

    /**
     * 分页查询判故逻辑列表
     *
     * @param judgeFaultLogicBo 判故逻辑Bo
     * @return 分页判故逻辑集合
     */
    PageResult<JudgeFaultLogicVo> selectPage(JudgeFaultLogicBo judgeFaultLogicBo);

    /**
     * 新增判故逻辑
     *
     * @param judgeFaultLogicBo 判故逻辑Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(JudgeFaultLogicBo judgeFaultLogicBo);

    /**
     * 新增判故逻辑，前台提供主键值，一般用于导入的场合
     *
     * @param judgeFaultLogicBo 判故逻辑Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(JudgeFaultLogicBo judgeFaultLogicBo);

    /**
     * 修改判故逻辑
     *
     * @param judgeFaultLogicBo 判故逻辑Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(JudgeFaultLogicBo judgeFaultLogicBo);

    /**
     * 批量删除判故逻辑
     *
     * @param ids 需要删除的判故逻辑主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * 异步导入
     *
     * @param file          导入的文件
     * @param updateSupport 是否覆盖
     * @param user          用户上下文信息
     */
    @Async
    void asyncImportData(MultipartFile file, boolean updateSupport, LoginUser user);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<JudgeFaultLogicVo> listVo, String sheetName, LoginUser user);

}
